<?php
/**
 * System Plugin for Joomla! - JMG Hot Panel
 * @package     Joomla.Site
 * @subpackage  jmghotpanel
 * @copyright   Copyright (C) 2021 - 2027 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;

/**
 * Class PlgSystemJmgHotPanel
 *
 * @since  1.0.0
 */
class PlgSystemJmgHotPanel extends CMSPlugin
{
	protected $autoloadLanguage = true;
	protected $app;
	protected $panels;
	protected $levels;
	
	function onBeforeCompileHead(){
		// Don't run this plugin in the Admin
		if ($this->app->isClient('administrator')){
			return;
		}
        
        if(!JComponentHelper::getComponent('com_jmghotpanel', true)->enabled){
            return;
        }
		
		$jinput = JFactory::getApplication()->input;
		if($jinput->get('tmpl') == 'component'){
			return;
		}
		
		HTMLHelper::_('stylesheet', 'com_jmghotpanel/jmghotpanel.css', array('version' => 'auto', 'relative' => true));
		HTMLHelper::_('stylesheet', 'com_jmghotpanel/jmgbuttonhover.css', array('version' => 'auto', 'relative' => true));
		HTMLHelper::_('stylesheet', 'com_jmghotpanel/jmgpaneleffects.css', array('version' => 'auto', 'relative' => true));
		HTMLHelper::_('stylesheet', 'com_jmghotpanel/modal.css', array('version' => 'auto', 'relative' => true));
		HTMLHelper::_('stylesheet', 'com_jmghotpanel/animate.css', array('version' => 'auto', 'relative' => true));
		HTMLHelper::_('stylesheet', 'com_jmghotpanel/fontawesome.css', array('version' => 'auto', 'relative' => true));
		HTMLHelper::_('script', 'com_jmghotpanel/jmghotpanel.js', array('version' => 'auto', 'relative' => true));
        
        \Joomla\CMS\HTML\HTMLHelper::_('bootstrap.collapse', '.selector', []);
		
		$this->panels = $this->getPanels();
		$style = '/* X-Small devices (portrait phones, less than 576px) */
		@media (max-width: 575.98px) {';
		foreach($this->panels as $panel){
			$style .= '
			.jmg-panel.panel-'.$panel->id.'{
			';
			foreach(json_decode($panel->params) as $object){
				$style .= $object->param.': '.$object->valuexsmall.';
				'; 
			}
			$style .= '}
			';
		}
		$style .= '
		}
		';
		
		
		$style .= '/* Small devices (landscape phones, 576px and up) */
		@media (min-width: 576px) {';
		foreach($this->panels as $panel){
			$style .= '
			.jmg-panel.panel-'.$panel->id.'{
			';
			foreach(json_decode($panel->params) as $object){
				$style .= $object->param.': '.$object->valuesmall.';
				'; 
			}
			$style .= '}
			';
		}
		$style .= '
		}
		';
		
		$style .= '/* Medium devices (tablets, 768px and up) */
		@media (min-width: 768px) {';
		foreach($this->panels as $panel){
			$style .= '
			.jmg-panel.panel-'.$panel->id.'{
			';
			foreach(json_decode($panel->params) as $object){
				$style .= $object->param.': '.$object->valuemedium.';
				'; 
			}
			$style .= '}
			';
		}
		$style .= '
		}
		';	
		
		$style .= '/* Large devices (desktops, 992px and up) */
		@media (min-width: 992px) {';
		foreach($this->panels as $panel){
			$style .= '
			.jmg-panel.panel-'.$panel->id.'{
			';
			foreach(json_decode($panel->params) as $object){
				$style .= $object->param.': '.$object->valuelarge.';
				'; 
			}
			$style .= '}
			';
		}
		$style .= '
		}
		';
		
		$style .= '/* X-Large devices (large desktops, 1200px and up) */
		@media (min-width: 1200px) {';
		foreach($this->panels as $panel){
			$style .= '
			.jmg-panel.panel-'.$panel->id.'{
			';
			foreach(json_decode($panel->params) as $object){
				$style .= $object->param.': '.$object->valuexlarge.';
				'; 
			}
			$style .= '}
			';
		}
		$style .= '
		}
		';

		$style .= '/* XX-Large devices (larger desktops, 1400px and up) */
		@media (min-width: 1400px) {';
		foreach($this->panels as $panel){
			$style .= '
			.jmg-panel.panel-'.$panel->id.'{
			';
			foreach(json_decode($panel->params) as $object){
				$style .= $object->param.': '.$object->valuexxlarge.';
				'; 
			}
			$style .= '}
			';
		}
		$style .= '
		}
		';

		JFactory::getDocument()->addStyleDeclaration( $style );
		
		$buttonstyles = $this->getButtonStyles();
		 
		foreach($buttonstyles as $buttonstyle){
			$style = array();
			$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.' a{';
			if($buttonstyle->radius)	$style[] = 'border-radius:' . $buttonstyle->radius . ';';
			if($buttonstyle->margin)	$style[] = 'margin:' . $buttonstyle->margin . ';';
			$style[] = '}';
			$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.' .jmg-button-div{';
			if($buttonstyle->radius)	$style[] = 'border-radius:' . $buttonstyle->radius . ';';
			$style[] = '}';
			$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.' .jmg-button-div .jmg-icon-div{';
			if($buttonstyle->width)			$style[] = 'width:' . $buttonstyle->width . ';';
			if($buttonstyle->height)		$style[] = 'height:' . $buttonstyle->height . ';';
			if($buttonstyle->padding)		$style[] = 'padding:' . $buttonstyle->padding . ';';
			if($buttonstyle->iconcolor)		$style[] = 'color:' . $buttonstyle->iconcolor . ';';
			if($buttonstyle->textalignment)	$style[] = 'text-align:' . $buttonstyle->textalignment . ';';
			if($buttonstyle->color)			$style[] = 'background-color:' . $buttonstyle->color . ';';
			if($buttonstyle->border)		$style[] = 'border:' . $buttonstyle->border . ';';
			if($buttonstyle->radius)		$style[] = 'border-radius:' . $buttonstyle->radius . ';';
			$style[] = 'box-sizing: content-box;';
			$style[] = '}';	
			$style[] = '.jmg-panel  .jmg-li-'.$buttonstyle->id.' .jmg-button-div span{';
			if($buttonstyle->textcolor)	$style[] = 'color:' . $buttonstyle->textcolor . ';';
			if($buttonstyle->textsize)	$style[] = 'font-size:' . $buttonstyle->textsize . ';';
			if($buttonstyle->textweight)$style[] = 'font-weight:' . $buttonstyle->textweight . ';';
			$style[] = '}';	
			if($buttonstyle->effect == 'illuminated-border'){
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.illuminated-border:hover a:before,';
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.illuminated-border:hover a:after{';
				if($buttonstyle->radius)	$style[] = 'border-radius:' . $buttonstyle->radius . ';';
				$style[] = '}';	
			}		
			if($buttonstyle->effect == 'clipme'){
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.clipme a:hover:before,';
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.clipme a:hover:after{';
				$style[] = 'background:' . $buttonstyle->effectcolor . ';';
				if($buttonstyle->radius)	$style[] = 'border-radius:' . $buttonstyle->radius . ';';
				$style[] = '}';	
			}				
			if($buttonstyle->effect == 'clippath-circle'){
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.clippath-circle a:hover .jmg-icon-div:before,';
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.clippath-circle a:hover .jmg-icon-div:after{';
				$style[] = 'background:' . $buttonstyle->effectcolor . ';';
				$style[] = '}';	
			}		
			if($buttonstyle->effect == 'framed'){
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.framed a:hover:before{';
				$style[] = 'border-top: 1px solid ' . $buttonstyle->effectcolor . ';';
				$style[] = 'border-left: 1px solid ' . $buttonstyle->effectcolor . ';';
				$style[] = '}';	
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.framed a:hover:after{';
				$style[] = 'border-top: 1px solid ' . $buttonstyle->effectcolor . ';';
				$style[] = 'border-right: 1px solid ' . $buttonstyle->effectcolor . ';';
				$style[] = '}';	
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.framed a:hover .jmg-button-div:before{';
				$style[] = 'border-bottom: 1px solid ' . $buttonstyle->effectcolor . ';';
				$style[] = 'border-left: 1px solid ' . $buttonstyle->effectcolor . ';';
				$style[] = '}';	
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.framed a:hover .jmg-button-div:after{';
				$style[] = 'border-bottom: 1px solid ' . $buttonstyle->effectcolor . ';';
				$style[] = 'border-right: 1px solid ' . $buttonstyle->effectcolor . ';';
				$style[] = '}';	
			}
			if($buttonstyle->effect == 'border-composition'){
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.border-composition a:hover:before,';
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.border-composition a:hover:after{';
				$style[] = 'background-image:   linear-gradient(to right, ' . $buttonstyle->effectcolor . ' 100%, ' . $buttonstyle->effectcolor . ' 100%),';
                $style[] = 'linear-gradient(to bottom, ' . $buttonstyle->effectcolor . ' 100%, ' . $buttonstyle->effectcolor . ' 100%),';     
                $style[] = 'linear-gradient(to right, ' . $buttonstyle->effectcolor . ' 100%, ' . $buttonstyle->effectcolor . ' 100%),';    
                $style[] = 'linear-gradient(to bottom, ' . $buttonstyle->effectcolor . ' 100%, ' . $buttonstyle->effectcolor . ' 100%);';     
				$style[] = '}';	
			}
			if($buttonstyle->effect == 'text-color'){
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.text-color a:hover .jmg-icon-wrap span{';
				$style[] = 'color:' . $buttonstyle->effectcolor . '!important;';
				$style[] = '}';	
			}
			if($buttonstyle->effect == 'icn-hover-color'){
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.icn-hover-color a:hover .jmg-icon-div{';
				$style[] = 'color:' . $buttonstyle->effectcolor . '!important;';
				$style[] = '}';	
			}
			if($buttonstyle->effect == 'flyout-text'){
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.flyout-text div.jmg-button-div .jmg-icon-wrap span{';
				$style[] = 'color:' . $buttonstyle->textcolor . '!important;';
				$style[] = 'background:' . $buttonstyle->effectcolor_2 . '!important;';
				$style[] = 'display: block!important;';
				$style[] = 'line-height: normal!important;';
				$style[] = 'padding: 10px 20px!important;';
				$style[] = '}';	
			}
			if($buttonstyle->effect == 'expand-button'){
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.expand-button div.jmg-button-div .jmg-icon-wrap span{';
				$style[] = 'color:' . $buttonstyle->textcolor . '!important;';
				$style[] = 'background:' . $buttonstyle->effectcolor_2 . '!important;';
				$style[] = 'height: ' . $buttonstyle->height . ';';
				$style[] = 'border-radius: '.$buttonstyle->radius.';';
				$style[] = '}';
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.expand-button div.jmg-button-div .jmg-icon-wrap.lft span{';
				$style[] = 'padding: 0 20px 0 ' . (((int)$buttonstyle->width / 1) + 20) . 'px;';
				$style[] = '}';
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.expand-button div.jmg-button-div .jmg-icon-wrap.lft:hover span{';
				$style[] = 'transform: translateX(-' . ((int)$buttonstyle->width / 1) . 'px);';
				$style[] = '}';
				
				
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.expand-button div.jmg-button-div .jmg-icon-wrap.rght span{';
				$style[] = 'padding: 0 ' . (((int)$buttonstyle->width / 1) + 20) . 'px 0 20px;';
				$style[] = '}';
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.expand-button div.jmg-button-div .jmg-icon-wrap.rght:hover span{';
				$style[] = 'transform: translateX(' . ((int)$buttonstyle->width / 1) . 'px);';
				$style[] = '}';
				
				
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.expand-button div.jmg-button-div .jmg-icon-wrap.rght:hover span{';
				$style[] = 'transform: translateX(' . ((int)$buttonstyle->width / 1) . 'px);';
				$style[] = '}';
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.expand-button div.jmg-button-div .jmg-icon-wrap{';
				$style[] = 'border-radius: '.$buttonstyle->radius.';';
				$style[] = '}';
			}		
			if($buttonstyle->effect == 'animate-tooltip'){
				$style[] = '.jmg-panel .jmg-li-'.$buttonstyle->id.'.animate-tooltip a:hover .jmg-icon-div{';
				$style[] = 'background-color:' . $buttonstyle->effectcolor . ';';
				$style[] = 'transition: background-color .3s linear;';
				$style[] = '}';	
			}
			
			$style = implode("\n", $style);
			JFactory::getDocument()->addStyleDeclaration( $style );
		}
		
		$boxstyles = $this->getBoxStyles();
		 
		foreach($boxstyles as $boxstyle){
			$style = array();
			$style[] = '.modal-'.$boxstyle->id.' .light-modal-content{';
			if($boxstyle->textcolor)	$style[] = 'color:' . $boxstyle->textcolor . ';';
			if($boxstyle->color)		$style[] = 'background-color:' . $boxstyle->color . ';';
			if($boxstyle->width)		$style[] = 'width:' . $boxstyle->width . ';';
			if($boxstyle->height)		$style[] = 'height:' . $boxstyle->height . ';';
			if($boxstyle->radius)		$style[] = 'border-radius:' . $boxstyle->radius . ';';
			if($boxstyle->padding)		$style[] = 'padding:' . $boxstyle->padding . ';';
			if($boxstyle->border)		$style[] = 'border:' . $boxstyle->border . ';';
			$style[] = '}';
			$style = implode("\n", $style);
			JFactory::getDocument()->addStyleDeclaration( $style );
		}
	}
	
	public function onAfterRender(){
		// Don't run this plugin in the Admin
		if ($this->app->isClient('administrator')){
			return;
		}
        
        if(!JComponentHelper::getComponent('com_jmghotpanel', true)->enabled){
            return;
        }
		
		$jinput = JFactory::getApplication()->input;
		if($jinput->get('tmpl') == 'component'){
			return;
		}
		
		$user   = JFactory::getUser();
		$this->levels = JAccess::getAuthorisedViewLevels($user->id);
		
		$body = $this->app->getBody();		
		$body = $this->buildPanels($body);
		$body = $this->buildModals($body);
		$this->app->setBody($body);
	}
	
	public function buildPanels($text){

		$html = array(); 
		
		//$app = JFactory::getApplication(); 
		$active = $this->app->getMenu()->getActive();

		foreach($this->panels as $panel){	
			if($panel->menuitems != '' && !in_array($active->id,json_decode($panel->menuitems,true)))continue;
			$cssclasses = ($panel->cssclasses)? implode(' ',json_decode($panel->cssclasses,true)) : '';
			$buttons = $this->getButtons($panel->id);
			$html[] = '<div class="jmg-panel panel-'.$panel->id.' '.$panel->alignment.' '.$panel->buttonalignment.' '.$panel->effect.' '.$panel->scrollspy.' '.$cssclasses.'">';
			
			
			switch ($panel->templateid)
			{
				case 1:	
				$html[] = '';
				break;	

				case 2:	
				$html[] = '<h4>'.$panel->name.'</h4>';
				break;

				case 3:	
				$html[] = '<h4>'.$panel->name.'</h4>';
				$html[] = $panel->description;
				break;
						
				case 4:	
				$html[] = '<div class="panel-group" id="accordion" role="tablist" aria-multiselectable="true">';
				$html[] = '<div class="panel panel-default">';
				$html[] = '<div class="panel-heading" role="tab" id="headingOne">';
				$html[] = '<h4 class="panel-title">';
				$html[] = '<button class="btn btn-link" type="button" data-bs-toggle="collapse" data-parent="#accordion" data-bs-target="#collapseOne" aria-expanded="true" aria-controls="collapseOne">';
				$html[] = '<i class="fas fa-bars"></i>';
				$html[] = '</button>';
				$html[] = '</h4>';
				$html[] = '</div>';
				$html[] = '<div id="collapseOne" class="panel-collapse collapse" role="tabpanel" aria-labelledby="headingOne">';
				$html[] = '<div class="panel-body">';
				break;
						
				case 5:	
				$html[] = '';
				break;
			}
			
			
			
			$html[] = '<ul>';
			foreach($buttons as $button){
				if($button->publish_up && $button->publish_up != '0000-00-00 00:00:00' && strtotime($button->publish_up) > strtotime($button->now))continue;
				if($button->publish_down && $button->publish_down != '0000-00-00 00:00:00' && strtotime($button->publish_down) < strtotime($button->now))continue;
				$cssclasses = ($button->cssclasses)? implode(' ',json_decode($button->cssclasses,true)) : '';
				$hideon = ($button->hideon)? implode(' ',json_decode($button->hideon,true)) : '';
				$html[] = '<li class="jmg-li-'.$button->id.' '.$button->effect.' '.$hideon.'">';
				switch ($button->actionid)
				{
					case 1:	
					$html[] = '<a class="'.$cssclasses.'" href="'.$button->externalurl.'" target="_blank">';
					break;	

					case 2:	
					$html[] = '<a class="'.$cssclasses.'" href="'.JRoute::_('index.php?Itemid='.$button->menuitemid).'">';
					break;

					case 3:	
					$html[] = '<a class="big '.$cssclasses.'" href="#box_'.$button->id.'">';
					break;
						
					case 4:	
					$html[] = '<a class="'.$cssclasses.'" href="#'.$button->anchor.'">';
					break;
						
					case 5:	
					$html[] = '<a class="'.$cssclasses.'" href="mailto:'.$button->email.'">';
					break;
						
					case 6:	
					$html[] = '<a class="'.$cssclasses.'" href="javascript:jmghotpanel_'.$button->functionid.'();">';
					break;
						
					case 7:	
					$html[] = '<a class="'.$cssclasses.'" href="'.JRoute::_('index.php?Itemid='.$button->menuitemid).'#'.$button->anchor.'">';
					break;
						
					case 8:	
					//$html[] = '<a class="'.$cssclasses.'" href="https://web.whatsapp.com/send?phone='.$button->whatsapp.'" target="_blank">';
					$html[] = '<a class="'.$cssclasses.'" href="https://wa.me/'.$button->whatsapp.'" target="_blank">';
					break;
						
					case 9:	
					$html[] = '<a class="'.$cssclasses.'" href="'.JURI::base().'">';
					break;
						
					case 12:	
					$html[] = '<a class="'.$cssclasses.'" href="tel:'.$button->phone.'">';
					break;
				}
				$html[] = '<div class="jmg-button-div '.$button->boxshadow.'">';
				switch ($button->templateid)
				{
					case 1:	
					if($button->buttonimage){	
						$html[] = '<div class="jmg-icon-div icn">';
						$html[] = '<img src="'.$button->buttonimage.'" alt="'.$button->name.'">';
						$html[] = '</div>';
					}
					else{
						$html[] = '<div class="jmg-icon-div icn">';
						$html[] = '<i class="'.$button->iconclass.' '.$button->iconsize.'"></i>';
						$html[] = '</div>';
					}
					break;	

					case 2:	
					$html[] = '<div class="jmg-icon-div txt">';
					$html[] = '<div class="labeling">'.$button->description.'</div>';
					$html[] = '</div>';
					break;

					case 3:	
					if($button->buttonimage){
						$html[] = '<div class="jmg-icon-wrap lft">';
						$html[] = '<div class="jmg-icon-div">';
						$html[] = '<img src="'.$button->buttonimage.'" alt="'.$button->name.'">';
						$html[] = '</div>';
						$html[] = '<span>'.$button->name.'</span>';
						$html[] = '</div>';
					}
					else{
						$html[] = '<div class="jmg-icon-wrap lft">';
						$html[] = '<div class="jmg-icon-div">';
						$html[] = '<i class="'.$button->iconclass.' '.$button->iconsize.'"></i>';
						$html[] = '</div>';
						$html[] = '<span>'.$button->name.'</span>';	
						$html[] = '</div>';	
					}
					break;
						
					case 4:	
					if($button->buttonimage){
						$html[] = '<div class="jmg-icon-wrap rght">';
						$html[] = '<span>'.$button->name.'</span>';
						$html[] = '<div class="jmg-icon-div">';
						$html[] = '<img src="'.$button->buttonimage.'" alt="'.$button->name.'">';
						$html[] = '</div>';					
						$html[] = '</div>';
					}
					else{
						$html[] = '<div class="jmg-icon-wrap rght">';
						$html[] = '<span>'.$button->name.'</span>';
						$html[] = '<div class="jmg-icon-div">';
						$html[] = '<i class="'.$button->iconclass.' '.$button->iconsize.'"></i>';
						$html[] = '</div>';						
						$html[] = '</div>';	
					}
					break;
						
					case 5:	
					if($button->buttonimage){
						$html[] = '<div class="jmg-icon-wrap btm">';
						$html[] = '<div class="jmg-icon-div">';
						$html[] = '<img src="'.$button->buttonimage.'" alt="'.$button->name.'">';
						$html[] = '<span>'.$button->name.'</span>';
						$html[] = '</div>';
						$html[] = '</div>';
					}
					else{
						$html[] = '<div class="jmg-icon-wrap btm">';
						$html[] = '<div class="jmg-icon-div">';
						$html[] = '<i class="'.$button->iconclass.' '.$button->iconsize.'"></i>';
						$html[] = '<span>'.$button->name.'</span>';
						$html[] = '</div>';
						$html[] = '</div>';
					}
					break;
						
					case 6:	
					if($button->buttonimage){
						$html[] = '<div class="jmg-tooltip-wrap">';
						$html[] = '<div class="jmg-tooltip-div center">';
						$html[] = '<span>'.$button->name.'</span>';
						$html[] = '</div>';
						$html[] = '<div class="jmg-icon-div center">';
						$html[] = '<img src="'.$button->buttonimage.'" alt="'.$button->name.'">';
						$html[] = '</div>';
						$html[] = '</div>';
					}
					else{
						$html[] = '<div class="jmg-tooltip-wrap">';
						$html[] = '<div class="jmg-tooltip-div center">';
						$html[] = '<span>'.$button->name.'</span>';
						$html[] = '</div>';
						$html[] = '<div class="jmg-icon-div center">';
						$html[] = '<i class="'.$button->iconclass.' '.$button->iconsize.'"></i>';				
						$html[] = '</div>';
						$html[] = '</div>';
					}
					break;
				}
				$html[] = '</div>';
				$html[] = '</a>';
				$html[] = '</li>';
			}
			$html[] = '</ul>';
			
			switch ($panel->templateid)
			{
				case 1:	
				$html[] = '';
				break;	

				case 2:	
				$html[] = '';
				break;

				case 3:	
				$html[] = '';
				break;
						
				case 4:	
				$html[] = '</div>';
				$html[] = '</div>';
				$html[] = '</div>';
				$html[] = '</div>';
				break;
						
				case 5:	
				$html[] = '';
				break;
			}
			
			$html[] = '</div>';
		}
		

		$text = str_replace('</body>',implode("\n", $html).'</body>', $text);
		return $text;
	}
	
	public function buildModals($text){
		$html = array(); 
		
		$active = $this->app->getMenu()->getActive();
		
		foreach($this->panels as $panel){
			if($panel->menuitems != '' && !in_array($active->id,json_decode($panel->menuitems,true)))continue;
			$buttons = $this->getButtons($panel->id);
			foreach($buttons as $button){
				if($button->actionid == 3){
					$modalbox = $this->getModalbox($button->boxid);
					
					$html[] = '<div class="light-modal  modal-'.$modalbox->id.' trigger-'.$modalbox->triggerid.' noselect" id="box_'.$button->id.'" role="dialog" aria-labelledby="light-modal-label" aria-hidden="false">';
					$html[] = '<div id="light-modal-box" class="light-modal-content animated '.$modalbox->effect.'">';
					
					switch ($modalbox->styleid)
					{
						case 1:	
						$html[] = '<!-- light modal header -->';
						$html[] = '<div class="light-modal-header dark">';
						$html[] = '<h3 id="modal-title" class="light-modal-heading">'.$modalbox->name.'</h3>';
						$html[] = '<a href="#/" class="light-modal-close-icon closemodal" aria-label="close">&times;</a>';
						$html[] = '</div>';
						break;	
							
						case 2:	
						$html[] = '<!-- light modal header -->';
						$html[] = '<div class="light-modal-header dark">';
						$html[] = '<h3 id="modal-title" class="light-modal-heading">'.$modalbox->name.'</h3>';
						$html[] = '<a href="#/" class="light-modal-close-icon closemodal" aria-label="close">&times;</a>';
						$html[] = '</div>';
						break;
							
						case 3:	
						$html[] = '<!-- light modal header -->';
						$html[] = '<div class="light-modal-header">';
						$html[] = '<h3 id="modal-title" class="light-modal-heading"></h3>';
						$html[] = '<a href="#/" class="light-modal-close-icon closemodal" aria-label="close">&times;</a>';
						$html[] = '</div>';
						break;
					}
									
					switch ($modalbox->templateid)
					{
						case 1:	
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$html[] = $modalbox->description;
						$html[] = '</div>';
						break;	

						case 2:	
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$html[] = '<img src="'.JURI::root().$modalbox->image.'" alt="'.$modalbox->name.'" />';
						$html[] = $modalbox->description;
						$html[] = '</div>';
						break;

						case 3:	
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$html[] = '<div class="light-modal-text padding-left">';
						$html[] = $modalbox->description;
						$html[] = '</div>';
						$html[] = '<div class="light-modal-image">';
						$html[] = '<img src="'.JURI::root().$modalbox->image.'" alt="'.$modalbox->name.'" />';
						$html[] = '</div>';
						$html[] = '</div>';
						break;

						case 4:	
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$html[] = '<div class="light-modal-image">';
						$html[] = '<img src="'.JURI::root().$modalbox->image.'" alt="'.$modalbox->name.'" />';
						$html[] = '</div>';
						$html[] = '<div class="light-modal-text padding-right">';
						$html[] = $modalbox->description;
						$html[] = '</div>';
						$html[] = '</div>';
						break;

						case 5:	
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$html[] = '<div class="light-modal-video">';
						$html[] = '<iframe src="https://www.youtube.com/embed/'.$modalbox->youtubeid.'" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>';
						$html[] = '</div>';
						$html[] = '</div>';
						break;

						case 6:	
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$html[] = '<div class="light-modal-video">';
						$html[] = '<iframe src="https://player.vimeo.com/video/'.$modalbox->vimeoid.'" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>';
						$html[] = '</div>';
						$html[] = '</div>';
						break;

						case 7:	
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$html[] = '<div class="light-modal-video">';
						$html[] = '<video src="'.JURI::root().$modalbox->mp4url.'" playsinline controls></video>';
						$html[] = '</div>';
						$html[] = '</div>';
						break;

						case 8:	
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$html[] = JControllerLegacy::getInstance('Content')->getModel('Article')->getItem($modalbox->articleid)->introtext;
						$html[] = '</div>';
						break;

						case 9:	
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$renderer = JFactory::getDocument()->loadRenderer('module');
						$contents = '';
						$db = JFactory::getDBO();
						$db->setQuery("SELECT * FROM `#__modules` WHERE id = '".$modalbox->moduleid."'");
						$modules = $db->loadObjectList();
						$module = $modules[0];  
						$html[] = $renderer->render($module); 
						$html[] = '</div>';
						break;
							
						case 10:	
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$html[] = '<div class="light-modal-iframe">';
						$html[] = '<iframe src="'.$modalbox->externalurl.'" frameborder="0"></iframe>';
						$html[] = '</div>';
						$html[] = '</div>';
						break;
							
						case 11:	
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$html[] = '<div class="light-modal-audio">';
						$html[] = '<audio src="'.JURI::root().$modalbox->mp3url.'" controls>';
						$html[] = '<p>Ihr Browser unterstützt kein HTML5 audio. <a href="'.JURI::root().$modalbox->mp3url.'" target="_blank">Hier klicken</a>'; 
						$html[] = 'um die Audiodatei herunterzuladen.</p></audio>';
						$html[] = '</div>';
						$html[] = '</div>';
						break;
							
						case 16:	
						$placeholdertel = ($modalbox->telfieldlabel)? $modalbox->telfieldlabel : JText::_('COM_JMGHOTPANEL_TELFIELDLABEL');
						$placeholdermail = ($modalbox->mailfieldlabel)? $modalbox->mailfieldlabel : JText::_('COM_JMGHOTPANEL_MAILFIELDLABEL');
						$sendbuttonlabel = ($modalbox->sendbuttonlabel)? $modalbox->sendbuttonlabel : JText::_('COM_JMGHOTPANEL_SENDBUTTONLABEL');
						$html[] = '<!-- light modal body -->';
						$html[] = '<div id="modal-body" class="light-modal-body">';
						$html[] = '<div id="jmg-call-back">';
						$html[] = $modalbox->description;
						$html[] = '<form id="jmg-call-back-form" action="'.JRoute::_('index.php?option=com_jmghotpanel&task=mailto.submit&id='.$modalbox->id).'" method="post" class="form-validate">';	
						$html[] = '<input class="call-back-phone" type="text" id="jform_phone" name="jform[phone]" value="" placeholder="'.$placeholdertel.'" required="required" />';
						$html[] = '<input class="call-back-mail" type="text" id="jform_mail" name="jform[mail]" value="" placeholder="'.$placeholdermail.'" required="required" />';
						$html[] = '<a role="button" class="btn btn-default jmg-submit-button">'.$sendbuttonlabel.'</a>';
						$html[] = '<input type="hidden" id="jform_id" name="jform[id]" value="'.$modalbox->id.'">';
						$html[] = JHtml::_('form.token');
						$html[] = '</form>';
						$html[] = '</div>';
						$html[] = '</div>';
						break;
					}
					
					switch ($modalbox->styleid)
					{
						case 1:	
						$html[] = '<!-- light modal footer -->';
						$html[] = '<div class="light-modal-footer">';
						$html[] = '<a href="#/" class="light-modal-close-btn closemodal" aria-label="close">'.JText::_('PLG_SYSTEM_JMGHOTPANEL_CLOSE').'</a>';
						$html[] = '</div>';
						break;	
					}
					
					$html[] = '</div>';
					$html[] = '</div>';
					$html[] = '<div class="big-modal">';
					$html[] = '</div>';
				}			
			}
		}
		
		$text = str_replace('</body>',implode("\n", $html).'</body>', $text);
		return $text;
	}
	
	//get the buttons of the current panel
	public function getButtons($panelid){
		
		$groups_list = '(' . implode(',', $this->levels) . ')';
		
		$db = JFactory::getDbo();
		$query = $db->getQuery(true)
			->select('a.id')
			->select('a.name AS name')
			->select('a.position')
			->select('a.templateid')
			->select('a.actionid')
			->select('a.boxid')
			->select('a.description')
			->select('a.iconsize')
			->select('a.color')
			->select('a.textcolor')
			->select('a.effect')
			->select('a.hideon')
			->select('a.boxshadow')
			->select('a.cssclasses')
			->select('a.menuitems')
			->select('a.buttonimage')
			->select('a.image')
			->select('a.youtubeid')
			->select('a.downloadurl')
			->select('a.moduleid')
			->select('a.mp3url')
			->select('a.phone')
			->select('a.externalurl')
			->select('a.anchor')
			->select('a.email')
			->select('a.whatsapp')
			->select('a.functionid')
			->select('a.menuitemid')
			->select('a.publish_up')
			->select('a.publish_down')
			->select('NOW() AS now')
			->select('i.class AS iconclass')
			->from('#__jmghotpanel_buttons AS a')
			->join('LEFT', '#__jmghotpanel_icons AS i ON a.iconid = i.id')
			->where('a.panelid = '.$panelid)
			->where('a.state = 1')
			->where('a.access IN ' . $groups_list)
			->order('a.ordering ASC');
		// Get the buttons.
		$db->setQuery($query);

		try
		{
			$buttons = $db->loadObjectList();
		}
		catch (RuntimeException $e)
		{
			JFactory::getApplication()->enqueueMessage(JText::_('PLG_SYSTEM_JMGHOTPANEL_COMPONENT_MISSING'));
			$buttons = array();
		}
		return $buttons;
	}
	
	public function getButtonStyles(){
		
		$db = JFactory::getDbo();
		$query = $db->getQuery(true)
			->select('a.id')
			->select('a.width')
			->select('a.height')
			->select('a.padding')
			->select('a.margin')
			->select('a.iconsize')
			->select('a.color')
			->select('a.textcolor')
			->select('a.textsize')
			->select('a.textweight')
			->select('a.iconcolor')
			->select('a.textalignment')
			->select('a.effectcolor')
			->select('a.effectcolor_2')
			->select('a.effect')
			->select('a.radius')
			->select('a.border')
			->from('#__jmghotpanel_buttons AS a')
			->where('a.state = 1');
		// Get the buttons.
		$db->setQuery($query);

		try
		{
			$buttons = $db->loadObjectList();
		}
		catch (RuntimeException $e)
		{
			JFactory::getApplication()->enqueueMessage(JText::_('PLG_SYSTEM_JMGHOTPANEL_COMPONENT_MISSING'));
			$buttons = array();
		}
		return $buttons;
	}
	
		
	public function getPanels(){
		
		$db = JFactory::getDbo();
		$query = $db->getQuery(true)
			->select('a.id')
			->select('a.name')
			->select('a.description')
			->select('a.templateid')
			->select('a.alignment')
			->select('a.scrollspy')
			->select('a.buttonalignment')
			->select('a.effect')
			->select('a.cssclasses')
			->select('a.color')
			->select('a.textcolor')
			->select('a.menuitems')
			->select('p.params')
			->from('#__jmghotpanel_panels AS a')
			->join('LEFT', '#__jmghotpanel_positions AS p ON a.position = p.id')
			->where('a.state = 1');

		// Get the panels.
		$db->setQuery($query);

		try
		{
			$panels = $db->loadObjectList();
		}
		catch (RuntimeException $e)
		{
			$panels = array();
		}
		
		return $panels;
	}
	
	public function getModalbox($boxid){
		
		$db = JFactory::getDbo();
		$query = $db->getQuery(true)
			->select('a.id')
			->select('a.name')
			->select('a.templateid')
			->select('a.styleid')
			->select('a.alignment')
			->select('a.triggerid')
			->select('a.color')
			->select('a.textcolor')
			->select('a.description')
			->select('a.image')
			->select('a.youtubeid')
			->select('a.vimeoid')
			->select('a.mp4url')
			->select('a.articleid')
			->select('a.moduleid')
			->select('a.externalurl')
			->select('a.telfieldlabel')
			->select('a.mailfieldlabel')
			->select('a.sendbuttonlabel')
			->select('a.mp3url')
			->select('a.effect')
			->from('#__jmghotpanel_boxes AS a')
			->where('a.state = 1')
			->where('a.id = '.$boxid);

		// Get the modalbox.
		$db->setQuery($query);

		try
		{
			$modalbox = $db->loadObject();
		}
		catch (RuntimeException $e)
		{
			//$modalbox = new Jobject;
		}
		return $modalbox;
	}
	
	public function getBoxStyles(){
		
		$db = JFactory::getDbo();
		$query = $db->getQuery(true)
			->select('a.id')
			->select('a.color')
			->select('a.textcolor')
			->select('a.width')
			->select('a.height')
			->select('a.radius')
			->select('a.padding')
			->select('a.border')
			->from('#__jmghotpanel_boxes AS a')
			->where('a.state = 1');
		// Get the boxes.
		$db->setQuery($query);

		try
		{
			$boxes = $db->loadObjectList();
		}
		catch (RuntimeException $e)
		{
			JFactory::getApplication()->enqueueMessage(JText::_('PLG_SYSTEM_JMGHOTPANEL_COMPONENT_MISSING'));
			$boxes = array();
		}
		return $boxes;
	}
}
